@@ -8,7 +8,7 @@ __END__
 
 =head1 NAME
 
-Bundle::Personal::lze
+Bundle::Personal::lze - Personal bundle include all Modules i used.
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,6 @@ XML::Twig
 XML::XSLT
 
 
-
 =head1 DESCRIPTION
 
 Personal Modulebundle
